import os
import sys
import time
from pprint import pprint
import re
from pyvirtualdisplay import Display

from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from robot.api import logger
from robot.utils import get_link_path
from robot.libraries.BuiltIn import BuiltIn, RobotNotRunningError

class RemoteUi:
	#ROBOT_LIBRARY_SCOPE = 'TEST SUITE'
	ROBOT_LIBRARY_SCOPE = 'GLOBAL'
	def __init__(self, ip, port=80, headless=True):
		self.ip = ip
		self.chrome_options = Options()
		if headless:
			self.chrome_options.add_argument("--headless")
			display = Display(visible=0, size=(1280, 960))
			display.start()

		self.chrome_options.add_experimental_option("detach", True)
		self.chrome_options.add_argument("--disable-infobars")
		self.chrome_options.add_argument("--disable-gpu")
		self.chrome_options.add_argument("--no-sandbox")
		self.driver = webdriver.Chrome('chromedriver', options=self.chrome_options)
		self.driver.implicitly_wait(3)
		self.driver.set_window_size(1280, 960)
		self.ui_loaded = False
		self.screenshot_path = ""

	@property
	def log_dir(self):
		try:
			logfile = BuiltIn().get_variable_value('${LOG FILE}')
			if logfile == 'NONE':
				return BuiltIn().get_variable_value('${OUTPUTDIR}')
			return os.path.dirname(logfile)
		except RobotNotRunningError:
			return os.getcwd()

	def load_ui(self):
		if not self.ui_loaded:
			self.driver.get("http://"+self.ip)
			self.ui_loaded = True
		else:
			self.driver.refresh()
			time.sleep(5)

	def location_should_start_with(self, url):
		m=re.match(r'^{0}'.format(url), self.driver.current_url)
		assert m, "Location is {0}, expected {1}".format(self.driver.current_url, url)

	def set_screenshot_path(self, path):
		self.screenshot_path = path

	def take_screenshot(self, name):
		path = "{path}{name}-{ts}.png".format(path=self.screenshot_path,name=name,ts=time.time())
		self.driver.save_screenshot(path)
		logger.info('</td></tr><tr><td colspan="3">'
					'<a href="{src}"><img src="{src}" width="{width}px"></a>'
					.format(src=get_link_path(path, self.log_dir), width=800), html=True)

	def click_on(self, element):
		if element[0] != "/":
			self.driver.find_element_by_css_selector(element).click()
		else:
			self.driver.find_element_by_xpath(element).click()
		time.sleep(0.5)

	def is_visible(self, element):
		e = None
		if element[0] != "/":
			e = self.driver.find_element_by_css_selector(element)
		else:
			e = self.driver.find_element_by_xpath(element)
		return e.is_displayed()

	def is_enabled(self, element):
		e = None
		if element[0] != "/":
			e = self.driver.find_element_by_css_selector(element)
		else:
			e = self.driver.find_element_by_xpath(element)
		return e.get_attribute("disabled") == None

	def click_ok(self, dialog):
		self.click_on("div[aria-describedby=\"" + dialog + "\"] div[class*=\"ui-dialog-buttonpane\"] button[role=\"button\"]")

	def is_scroll_visible(self, dialog):
		return self.is_visible("div[aria-describedby=\""+ dialog + "\"] div[class*=\"mCSB_scrollTools_vertical\"] a[class=\"mCSB_buttonDown\"]")

	def click_scroll_down(self, dialog):
		self.click_on("div[aria-describedby=\""+ dialog + "\"] div[class*=\"mCSB_scrollTools_vertical\"] a[class=\"mCSB_buttonDown\"]")

	def click_scroll_up(self, dialog):
		self.click_on("div[aria-describedby=\""+ dialog + "\"] div[class*=\"mCSB_scrollTools_vertical\"] a[class=\"mCSB_buttonUp\"]")

	def go_to_page(self, page):
		pages = {'Clone': "div#navbtn_clone",
				 'Image': "div#navbtn_clone",
				 'Hash': "div#navbtn_hash",
				 'Wipe': "div#navbtn_wipe",
				 'Push': "div#navbtn_push",
				 'Task Macro': "div#navbtn_task_macro",
				 'File Browser': "div#navbtn_file_browser",
				 'Logs': "div#navbtn_logs",
				 'Statistics': "div#navbtn_stats",
				 'Manage Repositories': "div#navbtn_manage_repos",
				 'System Settings': "div#navbtn_settings",
				 'Network Settings': "div#navbtn_network_settings",
				 'Software Updates': "div#navbtn_software",
				 'Power Off': "div#navbtn_restart"}
		element = pages[page]
		dirxn = 'down'
		i = 4
		while i > 0:
			if self.driver.find_element_by_css_selector(element).is_displayed():
				break
			if self.driver.find_element_by_css_selector("div#navbtn_restart").is_displayed():
				dirxn = 'up'
				i = 4
			self.click_on("div#nav_"+dirxn)
			i -= 1
		if self.driver.find_element_by_css_selector(element).is_displayed():
			self.click_on(element)
	
	def get_op_page(self, op):
		pages = {'Clone': "clone",
				 'Image': "clone",
				 'Hash': "hash",
				 'Wipe': "wipe",
				 'Push': "push"
		}
		return pages[op]

	def delete_all_tasks(self, op):
		self.go_to_page(op)
		page = self.get_op_page(op)
		for i in range(4, -1, -1):
			task = 'div#{0}_tab_{1}'.format(page, i)
			if self.driver.find_element_by_css_selector(task).is_displayed():
				self.click_on(task)
				self.click_on("div#" + page + "_delete_btn")
				self.click_ok(page + "_delete_dialog")
			else:
				pprint('{0}: not displayed?'.format(task))

	def add_tasks(self, op, num=1):
		self.go_to_page(op)
		page = self.get_op_page(op)
		for i in range(0, num):
			self.click_on("div#" + page + "_add_btn")

	def go_to_task(self, task):
		t = task.split(':')
		self.go_to_page(t[0])
		page = self.get_op_page(t[0])
		tab = 'div#{0}_tab_{1}'.format(page, int(t[1])-1)
		if self.driver.find_element_by_css_selector(tab).is_displayed():
			self.click_on(tab)

	def delete_task(self, task):
		self.go_to_task(task)
		t = task.split(':')
		page = self.get_op_page(t[0])
		self.click_on("div#" + page + "_delete_btn")
		self.click_ok(page + "_delete_dialog")

	def reset_task(self, task):
		self.go_to_task(task)
		t = task.split(':')
		page = self.get_op_page(t[0])
		reset = self.driver.find_element_by_css_selector("div#" + page + "_reset_btn")
		if reset.is_displayed():
			reset.click()
			self.click_ok(page + "_reset_dialog")

	def select_drives(self, op, type, filter=None):
		page = self.get_op_page(op)
		if isinstance(filter, list):
			filter = '|'.join(filter)
		pprint("select_drives: filter='{0}'".format(filter))
		self.click_on("div#{0}_{1}_btn".format(page, type.split('_')[0].lower()))
		time.sleep(2)
		table = self.driver.find_element_by_id('clone_{0}_select'.format(type.lower()))
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_scroll_down("clone_{0}_dialog".format(type.lower()))
			if 'ui-selected' not in row.get_attribute('class').split():
				row.click()
		self.click_ok("clone_{0}_dialog".format(type.lower()))

	def is_task_running(self, task):
		self.go_to_task(task)
		prog = self.driver.find_element_by_css_selector("div#clone_progressbar_info")
		if not prog.is_displayed():
			return False
		pprint(prog.text)
		return prog.text not in ['COMPLETED', 'ERROR', 'ABORTED']

	def wait_for_tasks(self, tasks):
		while len(tasks) > 0:
			for task in tasks:
				if self.is_task_running(task) is False:
					tasks.remove(task)
				time.sleep(10)

	def select_repositories(self, op, type, filter=None):
		page = self.get_op_page(op)
		if isinstance(filter, list):
			filter = '|'.join(filter)
		pprint("select_repositories: filter='{0}'".format(filter))
		self.click_on("div#{0}_{1}_btn".format(page, type.lower()))
		time.sleep(2)
		table = self.driver.find_element_by_id('clone_{0}_repo_select'.format(type.lower()))
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_scroll_down("clone_{0}_repo_dialog".format(type.lower()))
			if 'ui-selected' not in row.get_attribute('class').split():
				row.click()
		self.click_ok("clone_{0}_repo_dialog".format(type.lower()))

	def ScrollTableGetRows(self, dialog, table_id):
		table = self.driver.find_element_by_id(table_id)
		rows = table.find_elements_by_class_name("select_row")
		# Scroll through the list and make sure all rows are populated
		scroll = self.is_scroll_visible(dialog)
		while scroll:
			scroll = False
			for row in rows:
				while not row.is_displayed():
					self.click_scroll_down(dialog)
				col = row.find_elements(By.TAG_NAME, "td")[0]
				print("Column: " + col.text)
				if col.text == "":
					scroll = True
					time.sleep(1)
					break
			if scroll:
				rows = table.find_elements_by_class_name("select_row")

		# Go all the way to top
		while not rows[0].is_displayed():
			self.click_scroll_up(dialog)

		return rows

	def open_filesystem_selection(self, op, type, filter):
		page = self.get_op_page(op)
		self.click_on("div#{0}_{1}_btn".format(page, type.lower()))
		time.sleep(2)
		if isinstance(filter, list):
			filter = '|'.join(filter)

		# Scroll through the list and make sure all rows are populated
		rows = self.ScrollTableGetRows('push_filesystem_dialog', 'push_filesystem_select')
		# Go through the list and select the filesystem
		for row in rows:
			while not row.is_displayed():
				self.click_scroll_down("push_filesystem_dialog")

			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			if 'ui-selected' not in row.get_attribute('class').split():
				row.click()
		self.click_ok("push_filesystem_dialog".format(type.lower()))
		time.sleep(3)

	def select_directory_path(self, dlgname, path, check=False):
		assert(self.is_visible('div#{0}'.format(dlgname)))
		dlg = self.driver.find_element_by_css_selector('div[aria-describedby=\"{0}\"]'.format(dlgname))
		tree = dlg.find_element_by_class_name('jstree')
		down_btn = dlg.find_element_by_class_name('mCSB_buttonDown')
		dir = path.split('/')
		nlevels = len(dir)
		pprint("select_directory_path: levels='{0}'".format(nlevels))
		for level in dir:
			anchors = tree.find_elements_by_class_name("jstree-anchor")
			for anchor in anchors:
				if anchor.text == '':
					self.click_scroll_down(dlgname)
					time.sleep(2)
					continue
				elif anchor.text != level:
					pprint("select_directory_path skip: {0}".format(anchor.text))
					continue

				if nlevels <= 1:
					pprint("select_directory_path select: {0}".format(anchor.text))
					# when scroll downs are involved, single click does not seem to work
					# a few times oughta do it!
					elem = anchor
					if check:
						elem = anchor.find_elements_by_class_name("jstree-checkbox")[0]
					while 'jstree-clicked' not in anchor.get_attribute('class').split():
						elem.click()
						time.sleep(2)
				else:
					pprint("select_directory_path expanding: {0}".format(anchor.text))
					node = anchor.find_element_by_xpath("..")
					if 'jstree-closed' in node.get_attribute('class').split():
						icon = node.find_elements_by_class_name("jstree-icon")[0]
						icon.click()
					nlevels -= 1
					self.click_scroll_down(dlgname)
					time.sleep(1)
				break
		self.click_ok(dlgname)

	def get_task_status(self, task):
		self.go_to_task(task)
		prog = self.driver.find_element_by_css_selector("div#clone_progressbar_info")
		if not prog.is_displayed():
			return 'NONE'
		return prog.text

	def enter_text_in_keyboard(self, dialog, textbox, text):
		kbd = self.driver.find_element_by_id(dialog)
		name = kbd.find_element_by_id(textbox)
		name.clear()
		name.click()
		name.send_keys(text)

	def select_table_row(self, dialog, table, filter):
		table = self.driver.find_element_by_id(table)
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_scroll_down(dialog)
			if 'ui-selected' not in row.get_attribute('class').split():
				col.click()

	def create_directory_path(self, path):
		assert(self.is_visible('div#clone_capture_path_dialog'))
		dlg = self.driver.find_element_by_css_selector('div[aria-describedby=\"clone_capture_path_dialog\"]')
		add = dlg.find_element_by_id('clone_capture_path_add_btn')
		add.click()
		time.sleep(2)
		assert(self.is_visible('div#clone_capture_path_keyboard_dialog'))
		self.enter_text_in_keyboard('clone_capture_path_keyboard_dialog', 'capture_path_val', path)
		self.click_ok('clone_capture_path_keyboard_dialog')

	def select_repository_path(self, op, type, filter, path):
		page = self.get_op_page(op)
		if isinstance(filter, list):
			filter = '|'.join(filter)
		pprint("select_repository_path: filter='{0}'".format(filter))
		self.click_on("div#{0}_{1}_btn".format(page, type.lower()))
		time.sleep(2)
		# Scroll through the list and make sure all rows are populated
		table = self.driver.find_element_by_id('clone_{0}_repo_select'.format(type.lower()))
		rows = table.find_elements_by_class_name("select_row")
		nlevels = len(path.split('/'))
		pprint("select_repository_path: levels='{0}'".format(nlevels))
		for row in rows:
			col = row.find_elements_by_class_name("repo_name")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_scroll_down("clone_{0}_repo_dialog".format(type.lower()))

			if nlevels:
				col3 = row.find_elements(By.TAG_NAME, "td")[2]
				col3.click()
				time.sleep(2)
				self.create_directory_path(path)
				self.select_directory_path('clone_capture_path_dialog', path)
				time.sleep(1)
			if 'ui-selected' not in row.get_attribute('class').split():
				col.click()
		self.click_ok("clone_{0}_repo_dialog".format(type.lower()))

	def select_case(self, op, type, repo, path):
		self.open_filesystem_selection(op, type, repo)
		self.select_directory_path('push_case_dialog', path)

	def select_file_capture_dirs(self, dirs=[]):
		for dir in dirs:
			self.click_on("div[id=\"clone_files_dirs_block\"]")
			self.select_directory_path('clone_files_dirs_dialog', dir, check=True)
	
	def add_network_repository(self, name, path, domain, user, passwd, role='Both', source='Any'):
		roles = {'Source': 0, 'Destination': 1, 'Both': 2}
		self.go_to_page('Manage Repositories')
		self.click_on("div[id=\"manage_repos_tab_0\"]")
		self.click_on("div[id=\"manage_repos_add_btn\"]")
		assert(self.is_visible('div#manage_repos_add_dialog'))

		# enter repository name
		self.click_on("div[id=\"repo_name_block\"]")
		assert(self.is_visible('div#repo_name_dialog'))
		self.enter_text_in_keyboard('repo_name_dialog', 'repo_name_val', name)
		self.click_ok('repo_name_dialog')

		# select network share as repo type
		self.click_on("div[id=\"repo_drive_block\"]")
		assert(self.is_visible('div#repo_drive_dialog'))
		self.select_table_row('repo_drive_dialog', 'repo_drives_select', 'Network Share')
		self.click_ok('repo_drive_dialog')

		# select network repo source
		self.click_on("div[id=\"repo_network_source_block\"]")
		assert(self.is_visible('div#repo_network_source_dialog'))
		self.select_table_row('repo_network_source_dialog', 'repo_network_source_select', source)
		self.click_ok('repo_network_source_dialog')

		# set network repo destination
		self.click_on("div[id=\"repo_network_destination_block\"]")
		assert(self.is_visible('div#repo_network_keyboard_dialog'))
		self.enter_text_in_keyboard('repo_network_keyboard_dialog', 'repo_network_path_val', path)
		if user != 'NONE':
			self.enter_text_in_keyboard('repo_network_keyboard_dialog', 'repo_network_username_val', user)
		if domain != 'NONE':
			self.enter_text_in_keyboard('repo_network_keyboard_dialog', 'repo_network_domain_val', domain)
		if passwd != 'NONE':
			self.enter_text_in_keyboard('repo_network_keyboard_dialog', 'repo_network_password_val', passwd)
		self.click_ok('repo_network_keyboard_dialog')

		# select repo role
		self.click_on("div[id=\"repo_role_block\"]")
		assert(self.is_visible('div#repo_role_dialog'))
		self.click_on("div[id=\"repo_role_{0}\"]".format(roles[role]))
		self.click_ok('repo_role_dialog')
		self.click_ok('manage_repos_add_dialog')

	def delete_network_repository(self, name):
		self.go_to_page('Manage Repositories')
		self.click_on("div[id=\"manage_repos_tab_0\"]")
		table = self.driver.find_element_by_id('manage_repos_select')
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			regx = re.compile(name.upper())
			if regx.match(col.text) is None:
				print("Skipping: " + col.text)
				continue
			while not row.is_displayed():
				self.click_scroll_down(dialog)
			col6 = row.find_elements(By.TAG_NAME, "td")[6]
			col6.click()
			assert(self.is_visible('div#manage_repos_delete_dialog'))
			self.click_ok('manage_repos_delete_dialog')
			time.sleep(5)
		time.sleep(1)

