*** Settings ***
Documentation     A resource file with reusable keywords for backend test automation.

Resource        variables.robot
Library         Collections
Library         String
# XmlRpcApi <host> <port>
Library         XmlRpcApi	${HOST}	${PORT}
# SecureShell <host> <port> <headless?>
Library         SecureShell	${HOST}

*** Keywords ***
# Set Task Configuration	<task> <config>
# Set Task Configuration	Image:1|...|Push:5 &{cfg}
Set Task Configuration
	[Arguments]	${task}=${VARIABLE}	${cfg}=${VARIABLE}
	${tcfg}=	Convert To Dictionary	${cfg}
	Task Set Config	${task}	${tcfg}

# Set Wipe Format	<task> <fs> <enc>
# Set Wipe Format	Wipe:1|...|Wipe:5 ntfs|ext4|exfat|fat32|ext3|ext2|hfs+	${true}|${false}
Set Wipe Format
	[Arguments]	${task}=${VARIABLE}	${fs}=${VARIABLE}	${enc}=${VARIABLE}
	&{cfg}=	Create Dictionary	WipeFormat=${true}	WipeFilesystem=${fs}	EncryptEnable=${enc}
	Set Task Configuration	${task}	${cfg}

# Set Imaging Config	<task> <mode> <segment size> <comp>
# Set Imaging Config	Image:1|...|Image:5 DriveToE01|DriveToEx01|DriveToDD|DriveToDMG	2Gb|4Gb|8Gb|16Gb|WholeDisk	Default|None
Set Imaging Config
	[Arguments]  ${task}=${VARIABLE}	${mode}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}
	&{cfg}=	Create Dictionary	CloneMode=${mode}	SegmentSize=${segsz}	CompressionLevel=${comp}
	Set Task Configuration	${task}	${cfg}

# Start Task	<task>
# Start Task	Image:1|Wipe:3|Hash:1|Push:5
Start Task
	[Arguments]  ${task}=${VARIABLE}
	Task Run	${task}
	Sleep	5s
	${running}=	Is Task Running	${task}
	Should Be True	${running}

# Start All Tasks	[tasks]
# Start All Tasks	[Image:1, Wipe:2]
Start All Tasks
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Start Task	${t}
	END

# Confirm Task Successful	<task>
# Confirm Task Successful	Image:1
Confirm Task Successful
	[Arguments]  ${task}=${VARIABLE}
	${status}=	Task status Get	${task}
	Should Be Equal	${status}	TASK_COMPLETED

# Confirm All Tasks Successful	[tasks]
# Confirm All Tasks Successful	['Image:1', 'Wipe:2']
Confirm All Tasks Successful
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Confirm Task Successful	${t}
	END

Show All Drives
	@{src}    Get Source Drives
	FOR	${d}	IN	@{src}
		Log	${d}
	END
	@{dst}    Get Destination Drives
	FOR	${d}	IN	@{dst}
		Log	${d}
	END

Show All Bays
	@{src}    Get Source Bays
	FOR	${d}	IN	@{src}
		Log	${d}
	END
	@{dst}    Get Destination Bays
	FOR	${d}	IN	@{dst}
		Log	${d}
	END

Show All Pairs
	&{pairs}    Get All Pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
	END

Show All SAS SATA
	@{BAYS}=	Get All Bays	^SAS_|SATA_
	FOR	${B}	IN	${BAYS}
		Log	${B}
	END

Show One2One Pairs
	&{pairs}    Get Pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
	END
