*** Settings ***
Documentation     A resource file with reusable keywords for UI test automation.

Resource        variables.robot
Library         Selenium2Library
Library         Collections
Library         String
# XmlRpcApi <host> <port>
Library         XmlRpcApi	${HOST}	${PORT}
# RemoteUi <host> <port> <headless?>
Library         RemoteUi	${HOST}	${PORT}	${HEADLESS}
# SecureShell <host> <port> <headless?>
Library         SecureShell	${HOST}

*** Keywords ***
Load Remote UI
	Load Ui
	Location Should Start With	http://${HOST}/
	Get Host Statistics

# Set Image Case Name	<name>
# Set Image Case Name	<name>
# Set case name for Imaging task
Set Image Case Name
	[Arguments]  ${name}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_case_info_block"]
	Click On	//div[@id="clone_case_name_block"]
	Enter Text In Keyboard	clone_case_info_keyboard_dialog	case_info_val	${name}
	Click Ok	clone_case_info_keyboard_dialog
	Click Ok	clone_case_info_dialog
	Click Ok	clone_settings_dialog

# Set Hash Task Mode	<mode>
# Set Hash Task Mode	DriveHash|CaseVerify
# Set Mode for a hash task
Set Hash Task Mode
	[Arguments]  ${mode}=${VARIABLE}
	Click On	//div[@id="hash_mode_btn"]
	Click On	//div[@id="hash_mode_${hash_mode['${mode}']}"]
	Click Ok	hash_mode_dialog

# Set Hash Task Method	<hash method>
# Set Hash Task Method	SHA1|SHA256|MD5
# Set Hash Method type for a hash task
Set Hash Task Method
	[Arguments]  ${hash}=${VARIABLE}
	Click On	//div[@id="hash_settings_btn"]
	Click On	//div[@id="hash_values_btn"]
	Click On	//div[@id="hash_method_${hash_method['${hash}']}"]
	Click Ok	hash_values_dialog
	Click Ok	hash_settings_dialog

# Set Case Verify Mode	<mode>
# Set Case Verify Mode	PRIMARY|BOTH
# Set Case Verify Mode type for a hash task
Set Case Verify Mode
	[Arguments]  ${verify}=${VARIABLE}
	Click On	//div[@id="hash_settings_btn"]
	Click On	//div[@id="hash_verify_btn_top"]
	Click On	//div[@id="hash_verify_${case_verify['${verify}']}"]
	Click Ok	hash_verify_dialog
	Click Ok	hash_settings_dialog

# Set Push Verify Mode	<mode>
# Set Push Verify Mode	PRIMARY|BOTH
# Set Push Verify Mode type for a push task
Set Push Verify Mode
	[Arguments]  ${verify}=${VARIABLE}
	Click On	//div[@id="push_settings_btn"]
	Click On	//div[@id="push_verif_block"]
	Click On	//div[@id="push_verif_${push_verify['${verify}']}"]
	Click Ok	push_verif_dialog
	Click Ok	push_settings_dialog

# Set Imaging Mode	<imaging mode>
# Set Imaging Mode	DriveToDrive|FileToDrive|DriveToFile|FileToFile|PartToFile|NetToFile|MobileToFile
Set Imaging Mode
	[Arguments]  ${mode}=${VARIABLE}
	Click On	//div[@id="clone_mode_btn"]
	Click On	//div[@id="clone_mode_${clone_mode['${mode}']}"]
	Click Ok	clone_mode_dialog

# Set Clone Hash Method	<hash method>	<verify>
# Set Clone Hash Method	SHA1|SHA256|MD5	True|False
# Setup hash method for Mirror/Clever Clone
Set Clone Hash Method
	[Arguments]  ${hash}=${VARIABLE}	${verify}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_verif_block"]
	Click On	//div[@id="clone_hash_${hash_method['${hash}']}"]
	Run Keyword If	${verify}	Click On	//div[@id="clone_verif_0"]
	...	ELSE	Click On	//div[@id="clone_verif_1"]
	Click Ok	clone_verif_dialog
	Click Ok	clone_settings_dialog

# Set Image Hash Method	<hash method>	<verify type>
# Set Image Hash Method	SHA1|SHA256|MD5|SHA1MD5|SHA1SHA256|MD5SHA256	NO|PRIMARY|BOTH
Set Image Hash Method
	[Arguments]  ${hash}=${VARIABLE}	${verify}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_verif_block"]
	Click On	//div[@id="clone_hash_${hash_method['${hash}']}"]
	Click On	//div[@id="clone_verif_${image_verify['${verify}']}"]
	Click Ok	clone_verif_dialog
	Click Ok	clone_settings_dialog

# Set Image Method	<capture method>	<segment size>
# Set Image Method	DD|E01|EX01|DMG	2GB|4GB|8GB|16GB|WHOLEDISK
Set Image Method
	[Arguments]  ${method}=${VARIABLE}	${segsz}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_mc_block"]
	Click On	//div[@id="clone_capture_${image_method['${method}']}"]
	Click On	//div[@id="clone_segment_block"]
	Click On	//div[@id="clone_segment_${seg_size['${segsz}']}"]
	Click Ok	clone_segment_dialog
	Click Ok	clone_file_image_dialog
	Click Ok	clone_settings_dialog

# Set F2F Method	<output format>
# Set F2F Method	L01|LX01|DIR|MFT|ZIP
Set F2F Method
	[Arguments]  ${fmt}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_mc_block"]
	Click On	//div[@id="clone_output_format_${f2f_method['${fmt}']}"]
	Click Ok	clone_output_format_dialog
	Click Ok	clone_settings_dialog

# Set F2F Segment Settings	<segment size>	<compression>
# Set F2F Segment Settings	2GB|4GB|8GB|16GB|WhoeDisk	True|False
Set F2F Segment Settings
	[Arguments]  ${segsz}=${VARIABLE}	${comp}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_mc_block"]
	Click On	//div[@id="clone_output_segment_block"]
	Click On	//div[@id="clone_segment_${seg_size['${segsz}']}"]
	Click Ok	clone_segment_dialog
	Click On	//div[@id="clone_output_compression_block"]
	Run Keyword If	${comp}	Click On	//div[@id="clone_dco_1"]
	...	ELSE	Click On	//div[@id="clone_dco_0"]
	Click Ok	clone_compression_dialog
	Click Ok	clone_output_format_dialog
	Click Ok	clone_settings_dialog

# Set Image Compression	True|False
Set Image Compression
	[Arguments]  ${comp}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_mc_block"]
	Click On	//div[@id="clone_compression_block"]
	Run Keyword If	${comp}	Click On	//div[@id="clone_dco_1"]
	...	ELSE	Click On	//div[@id="clone_dco_0"]
	Click Ok	clone_compression_dialog
	Click Ok	clone_file_image_dialog
	Click Ok	clone_settings_dialog

# Set Wipe Format	<filesystem>	<encrypt>
# Set Wipe Format	NTFS|EXT4|EXFAT|FAT32|EXT3|EXT2|HFS+	True|False
Set Wipe Format
	[Arguments]  ${fs}=${VARIABLE}	${enc}=${VARIABLE}
	Click On	//div[@id="wipe_settings_btn"]
	Click On	//div[@id="wipe_format_btn"]
	Click On	//div[@id="wipe_format_0"]
	Click On	//div[@id="wipe_format_file_system_${wipe_fs['${fs}']}"]
	Run Keyword If	${enc}	Click On	//div[@id="wipe_format_encryption_0"]
	...	ELSE	Click On	//div[@id="wipe_format_encryption_1"]
	Click Ok	wipe_format_dialog
	Click Ok	wipe_settings_dialog

# Select F2F Source Path	<list of path>
# 	@{dirs}=	Create List	partn-2_FAT32/EFI/Microsoft/Recovery	partn-2_FAT32/System Volume Information/ClientRecoveryPasswordRotation
#	Select F2F Source Path	${dirs}
Select F2F Source Path
	[Arguments]  ${dirs}=${VARIABLE}
	Click On	//div[@id="clone_settings_btn"]
	Click On	//div[@id="clone_filter_settings_block"]
	Click On	//div[@id="clone_path_filter_block"]
	Select File Capture Dirs	${dirs}
	Click Ok	clone_path_filter_dialog
	Click Ok	clone_filter_settings_dialog
	Click Ok	clone_settings_dialog

# Start Task	<operation>	<task id>
# Start Task	Image|Wipe|Hash|Push	1|2|3|4|5
Start Task
	[Arguments]  ${task}=${VARIABLE}
	Go To Task	${task}
	Wait Until Keyword Succeeds	15s	5s	Is Enabled	//div[@id="clone_start_btn"]
	Sleep	2s
	Click On	//div[@id="clone_start_btn"]
	Click Ok	clone_start_dialog
	Sleep	5s
	Wait Until Keyword Succeeds	15s	3s	Is Visible	//div[@id="clone_progressbar_info"]

# Start All Tasks	[tasks]
# Start All Tasks	[Image:1, Wipe:2]
Start All Tasks
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Start Task	${t}
	END

Wait For Task
	[Arguments]  ${task}=${VARIABLE}
	${tasks}=	Create List	${task}
	Wait For Tasks	${tasks}

# Confirm Task Successful	<task>
# Confirm Task Successful	Image:1
Confirm Task Successful
	[Arguments]  ${task}=${VARIABLE}
	${status}=	Get Task status	${task}
	Take Screenshot	${TEST NAME}
	Should Be Equal	${status}	COMPLETED

# Confirm All Tasks Successful	[tasks]
# Confirm All Tasks Successful	['Image:1', 'Wipe:2']
Confirm All Tasks Successful
	[Arguments]  @{tasks}=${VARIABLE}
	FOR	${t}	IN	@{tasks}
		Confirm Task Successful	${t}
	END

Show All Drives
	@{src}    Get Source Drives
	FOR	${d}	IN	@{src}
		Log	${d}
	END 
	@{dst}    Get Destination Drives
	FOR	${d}	IN	@{dst}
		Log	${d}
	END 

Show All Bays
	@{src}    Get Source Bays
	FOR	${d}	IN	@{src}
		Log	${d}
	END 
	@{dst}    Get Destination Bays
	FOR	${d}	IN	@{dst}
		Log	${d}
	END 

Show All Pairs
	&{pairs}    Get All Pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
	END 

Show All SAS SATA
	@{BAYS}=	Get All Bays	^SAS_|SATA_
	FOR	${B}	IN	${BAYS}
		Log	${B}
	END
