*** Settings ***
Documentation     Test script for FNG-350

Resource          ${LIBRARY}/resource.be.robot

*** Comments ***
# Following Variables can be overridden via commandline arguments
# comp: Compression - use COMP:Default or COMP:None
# source: use SOURCE:<pattern/port name>. for e.g. SOURCE:^SAS_S for any SAS drive or SOURCE:SAS_S1
# dest: use DEST:<pattern/port name>. for e.g. DEST:^SAS_D for any SAS drive or DEST:SAS_D1
# fs: Destination Filesystem - use FS:<filesystem>. Where filesystem can be ntfs, ext4, exfat, fat, ext3, ext4, hfsp
# enc: Encryption - use ENC:True or ENC:False
# hash: Hash method - use HASH:<hash type>. Where hash type can be SHA-1, MD5, SHA1-MD5
# For e.g ./run_test -h 192.168.5.49 -t testcases/falcon-neo/backend/fng-350-bugtest.robot -v COMP:Default -v DEST:SAS_D2 -v FS:ntfs

*** Variables ***
${source}	^PCIe_S1
${fs}	ext4
${dest}	^SAS_D
${source_hash}	NONE
${hash}	SHA-1
${enc}	${false}
${comp}	None

*** Keywords ***
Capture D2F
	[Arguments]	${task}=${VARIABLE}	${mode}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}
	Set Imaging Config	${task}	${mode}	${segsz}	${comp}
	Task Set Master	${task}	${source}
	Task Set Hash	${task}	${hash}	Primary
	Task Set Repositories	${task}	${dest}
	Start Task	${task}
	${tasks}=	Create List	${task}
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}
	${hash}=	Task Get Expected Hash	${task}
	Should Be Equal	${source_hash}	${hash}
	Task Delete	${task}

Wipe Format
	[Arguments]	${task}=${VARIABLE}	${fs}=${VARIABLE}	${enc}=${VARIABLE}
	Task Add	${task}
	Task Set Targets	${task}	${dest}
	Set Wipe Format	${task}	${fs}	${enc}
	Start Task	${task}
	${tasks}=	Create List	${task}
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	Task Delete	${task}

*** Test Cases ***
TEST_PREP
	Show All Drives
	Show All Bays
	Show All Pairs
	Task Delete All	Image
	Task Delete All	Wipe
	Task Delete All	Hash
	#Task Delete All	Push

CALCULATE_SRC_HASH
	[Tags]    no_tag
	Task Add	Hash:2
	Task Set Targets	Hash:2	${source}
	Task Set Hash	Hash:2	${hash}
	Start Task	Hash:2
	${tasks}=	Create List	Hash:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	${hash}=	Task Get Source Hash	Hash:2	${source}
	Set Global Variable	${source_hash}	${hash}
	Task Delete	Hash:2

IMAGE_D2F_E01_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	Capture D2F	Image:1	DriveToE01	2Gb	${comp}

IMAGE_D2F_EX01_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	Capture D2F	Image:1	DriveToEx01	4Gb	${comp}

IMAGE_D2F_DD_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	Capture D2F	Image:1	DriveToDD	8Gb	None

IMAGE_D2F_DMG_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	Capture D2F	Image:1	DriveToDMG	16Gb	None

*** Comments ***
IMAGE_D2F_DD_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	@{segs}=	Create List	2Gb	4Gb	8Gb	16Gb
	FOR	${sz}	IN	@{segs}
		Capture D2F	Image:1	DriveToDD	${sz}	None
	END

IMAGE_D2F_DMG_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	@{segs}=	Create List	2Gb	4Gb	8Gb	16Gb
	FOR	${sz}	IN	@{segs}
		Capture D2F	Image:1	DriveToDMG	${sz}	None
	END

IMAGE_D2F_E01_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	@{segs}=	Create List	2Gb	4Gb	8Gb	16Gb
	FOR	${sz}	IN	@{segs}
		Capture D2F	Image:1	DriveToE01	${sz}	None
	END

IMAGE_D2F_EX01_ALL_SEGSZ
	Wipe Format	Wipe:1	${fs}	${enc}
	@{segs}=	Create List	2Gb	4Gb	8Gb	16Gb
	FOR	${sz}	IN	@{segs}
		Capture D2F	Image:1	DriveToEx01	${sz}	None
	END
