*** Settings ***
Documentation     Sample test cases to develop framework/library

Resource          ${LIBRARY}/resource.be.robot

*** Variables ***
#${source}	^PCIe_S1
${source}	^SAS_S2
${source_hash}	NONE

*** Test Cases ***
TEST_PREP
	Show All Drives
	Show All Bays
	Show All Pairs
	Show One2One Pairs
	Task Delete All	Image
	Task Delete All	Wipe
	Task Delete All	Hash
	#Task Delete All	Push
	Drop All Checkpoints

WIPE_FORMAT_ALL_NTFS
	[Tags]    no_tag
	Task Add	Wipe:2
	Task Set Targets	Wipe:2
	Set Wipe Format	Wipe:2	ntfs	${false}
	Start Task	Wipe:2
	${tasks}=	Create List	Wipe:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}

IMAGE_D2F_EX01_8G_SHA1_DYNAMIC
	[Tags]    no_tag
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
		Run Keyword If	${task} > 1	Task Add	Image:${task}
		Set Imaging Config	Image:${task}	DriveToEx01	8Gb	None
		Task Set Master	Image:${task}	${p}[0]
		Task Set Hash	Image:${task}	SHA-1	Primary
		Task Set Repositories	Image:${task}	${p}[1]
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

*** Comment ***
# TEST CASES IN THE *COMMENT* SECTION ARE NOT EXECUTED

HASH_SHA1
	[Tags]    no_tag
	Task Add	Hash:2
	Task Set Targets	Hash:2	${source}
	Task Set Hash	Hash:2	SHA-1
	Start Task	Hash:2
	${tasks}=	Create List	Hash:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	${hash}=	Task Get Source Hash	Hash:2	${source}
	Set Global Variable	${source_hash}	${hash}
	Task Delete	Hash:2

WIPE_FORMAT_SAS_EXT4
	[Tags]    no_tag
	Task Add	Wipe:2
	Task Set Targets	Wipe:2	^SAS_
	Set Wipe Format	Wipe:2	ext4	${false}
	Start Task	Wipe:2
	${tasks}=	Create List	Wipe:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}

IMAGE_D2F_DD_16G_SHA1
	[Tags]    no_tag
	Set Imaging Config	Image:1	DriveToDD	16Gb	None
	Task Set Master	Image:1	${source}
	Task Set Hash	Image:1	SHA-1	Primary
	Task Set Repositories	Image:1	^SAS_D
	Start Task	Image:1
	${tasks}=	Create List	Image:1
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}
	${hash}=	Task Get Expected Hash	Image:1
	Should Be Equal	${source_hash}	${hash}

HASH_SHA1_NOT_100PCT
	[Tags]    no_tag
	Task Add	Hash:2
	Task Set Targets	Hash:2	${source}
	Task Set Hash	Hash:2	SHA-1
	&{cfg}=	Create Dictionary	LBACount=4096000
	Set Task Configuration	Hash:2	${cfg}
	Start Task	Hash:2
	${tasks}=	Create List	Hash:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}
	${hash}=	Task Get Source Hash	Hash:2	${source}
	Set Global Variable	${source_hash}	${hash}
	Task Delete	Hash:2

WIPE_FORMAT_ALL_EXT4
	[Tags]    no_tag
	Task Add	Wipe:2
	Task Set Targets	Wipe:2	^SAS_
	Set Wipe Format	Wipe:2	ext4	${false}
	Start Task	Wipe:2
	${tasks}=	Create List	Wipe:2
	Wait For Task Completion	${tasks}
	Confirm All Tasks Successful	${tasks}

IMAGE_D2F_EX01_8G_SHA1_DYNAMIC
	[Tags]    no_tag
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get All Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Log	${p}
		Run Keyword If	${task} > 1	Task Add	Image:${task}
		Set Imaging Config	Image:${task}	DriveToEx01	8Gb	None
		Task Set Master	Image:${task}	${p}[0]
		Task Set Hash	Image:${task}	SHA-1	Primary
		Task Set Repositories	Image:${task}	${p}[1]
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

IMAGE_D2F_E01_2G_SHA1_MD5
	[Tags]    no_tag
	Set Imaging Config	Image:1	DriveToE01	2Gb	Default
	Task Set Master	Image:1	${source}
	Task Set Hash	Image:1	SHA1-MD5	Both
	Task Set Repositories	Image:1	^SAS_D
	Start Task	Image:1
	${tasks}=	Create List	Image:1
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

IMAGE_D2D_SHA1_VERIFY
	[Tags]    no_tag
	Set Imaging Config	Image:1	DriveToDrive	2Gb	Default
	Task Set Master	Image:1	${source}
	Task Set Hash	Image:1	SHA-1	${true}
	Task Set Targets	Image:1	^SAS_D
	Start Task	Image:1
	${tasks}=	Create List	Image:1
	# Wait for all tasks to end
	Wait For Task Completion	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}
