*** Settings ***
Documentation     DriveToFile Capture with case verify
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Take Screenshot	${TEST NAME}

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS

*** Keywords ***
Setup DriveToFile
	[Arguments]	${task}=${VARIABLE}	${mode}=${VARIABLE}	${src}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	Run Keyword If	${task} > 1	Add Tasks	Image	1
	Go To Task	Image:${task}
	Set Imaging Mode	DriveToFile
	Select Drives	Image	Master	${src}
	Set Image Case Name	${name}
	Set Image Hash Method	${HASH}	${VRFY}
	Set Image Method	${mode}	${segsz}
	Run Keyword If	'${mode}' != 'DD' and '${mode}' != 'DMG'	Set Image Compression	${comp}
	Select Repository Path	Image	Target	${dst}	${path}

Capture Ex01
	[Arguments]	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${path}=${VARIABLE}
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Setup DriveToFile	${task}	EX01	${p}[0]	${name}	${segsz}	${comp}	${p}[1]	${path}
		Append To List	${tasks}	Image:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Tasks	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

Setup CaseVerify
	[Arguments]	${task}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	Run Keyword If	${task} > 1	Add Tasks	Hash	1
	Go To Task	Hash:${task}
	Set Hash Task Mode	CaseVerify
	Select Case	Hash	Target	${dst}	${path}
	Set Case Verify Mode	${VRFY}

Verify DriveToFile
	[Arguments]	${path}=${VARIABLE}
	@{tasks}=	Create List
	${task}=	Set Variable	1
	# Get all source/destination pairs
	&{pairs}    Get Pairs

	# Setup a task for each of the pairs
	FOR	${p}	IN	&{pairs}
		Setup CaseVerify	${task}	${p}[1]	${path}
		Append To List	${tasks}	Hash:${task}
		${task}=	Evaluate	${task} + 1
	END

	# Start all tasks
	Start All Tasks	${tasks}
	# Wait for all tasks to end
	Wait For Tasks	${tasks}
	# Confirm all tasks successful
	Confirm All Tasks Successful	${tasks}

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Delete All Tasks	Image
	Delete All Tasks	Hash
	Delete All Tasks	Wipe

WIPE_FORMAT_ALL
	[Tags]    no_tag
	Add Tasks	Wipe	1
	Go To Task	Wipe:2
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:2
	Wait For Task	Wipe:2

IMAGE_D2F_EX01_2GB_SHA1
	Capture Ex01	2gb_no_comp	2GB	${false}	ex01_cap_test
	Verify DriveToFile	ex01_cap_test/2gb_no_comp
