*** Settings ***
Documentation     Tests for validating push task for Drive To File captures
Resource          ${LIBRARY}/resource.ui.robot
Test Setup        Load Remote UI
Test Teardown     Take Screenshot	${TEST NAME}

*** Variables ***
${HASH}	SHA1
${VRFY}	PRIMARY
${FRMT}	NTFS
${CSRC}	NONE
${CDST}	NONE
${PDST}	NONE
${HOST}	test-unit

${NAS_PATH}	192.168.1.23/upload
${NAS_USER}	logicube
${NAS_PSWD}	logicube

*** Keywords ***
Set Host Identification
	${host}	Get Unit Identifier
	Set Global Variable	${HOST}	${host}

Set Source
	@{src}	Get Source Bays
	Set Global Variable	${CSRC}	${src}[0]

Setup NAS Push Destination
	Delete Network Repository	nas
	Add Network Repository	nas	${NAS_PATH}	WORKGROUP	${NAS_USER}	${NAS_PSWD}	Both	Any
	Set Global Variable	${PDST}	nas

Setup DriveToFile
	[Arguments]	${task}=${VARIABLE}	${mode}=${VARIABLE}	${src}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${dst}=${VARIABLE}	${path}=${VARIABLE}
	Run Keyword If	${task} > 1	Add Tasks	Image	1
	Go To Task	Image:${task}
	Set Imaging Mode	DriveToFile
	Select Drives	Image	Master	${src}
	Set Image Case Name	${name}
	Set Image Hash Method	${HASH}	${VRFY}
	Set Image Method	${mode}	${segsz}
	Run Keyword If	'${mode}' != 'DD' and '${mode}' != 'DMG'	Set Image Compression	${comp}
	Select Repository Path	Image	Target	${dst}	${path}

Capture DriveToFile
	[Arguments]	${method}=${VARIABLE}	${name}=${VARIABLE}	${segsz}=${VARIABLE}	${comp}=${VARIABLE}	${path}=${VARIABLE}
	Setup DriveToFile	1	${method}	${CSRC}	${name}	${segsz}	${comp}	${CDST}	${path}
	Start Task	Image:1
	Wait For Task	Image:1
	Confirm Task Successful	Image:1
	Delete Task	Image:1

Push Capture
	[Arguments]	${src}=${VARIABLE}	${src_path}=${VARIABLE}	${dst}=${VARIABLE}	${dst_path}=${VARIABLE}
	Go To Task	Push:1
	Select Case	Push	Master	${src}	${src_path}
	Set Push Verify Mode	YES
	Select Repository Path	Push	Target	${dst}	${dst_path}
	Start Task	Push:1
	Wait For Task	Push:1
	Confirm Task Successful	Push:1
	Delete Task	Push:1

*** Test Cases ***
TEST_PREP
	Set Screenshot Path    ${RESULTS}/pics/
	Delete All Tasks	Image
	Delete All Tasks	Wipe
	Delete All Tasks	Push
	Drop All Checkpoints
	Run Keyword If	'${CSRC}' == 'NONE'	Set Source
	@{dst}    Get Destination Bays
	${ndst}=	Get Length	${dst}
	Log	${ndst}
	Run Keyword If	'${CDST}' == 'NONE' and ${ndst} > 0	Set Global Variable	${CDST}	${dst}[0]
	Run Keyword If	'${PDST}' == 'NAS'	Setup NAS Push Destination
	Run Keyword If	'${PDST}' == 'NONE' and ${ndst} > 1	Set Global Variable	${PDST}	${dst}[1]
	# If push destination is still NONE,
	Run Keyword If	'${PDST}' == 'NONE'	Setup NAS Push Destination
	Run Keyword If	'${HOST}' == 'test-unit'	Set Host Identification
	Log	${CSRC}
	Log	${CDST}
	Log	${PDST}

WIPE_FORMAT_DST
	[Tags]    no_tag
	Go To Task	Wipe:1
	@{dst}    Get Destination Bays
	Select Drives	Wipe	Target	${dst}
	Set Wipe Format	${FRMT}	False
	Start Task	Wipe:1
	Wait For Task	Wipe:1
	Confirm Task Successful	Wipe:1

IMAGE_CAPTURE_E01
	Capture DriveToFile	E01	2gb	2GB	${false}	${HOST}/e01_test
	Capture DriveToFile	E01	4gb	4GB	${true}	${HOST}/e01_test
	Capture DriveToFile	E01	8gb	8GB	${false}	${HOST}/e01_test
	Capture DriveToFile	E01	16gb	16GB	${true}	${HOST}/e01_test
	Push Capture  ${CDST}	${HOST}/e01_test	${PDST}	${HOST}/e01_push_test

IMAGE_CAPTURE_EX01
	Capture DriveToFile	EX01	2gb	2GB	${false}	${HOST}/ex01_test
	Capture DriveToFile	EX01	4gb	4GB	${true}	${HOST}/ex01_test
	Capture DriveToFile	EX01	8gb	8GB	${false}	${HOST}/ex01_test
	Capture DriveToFile	EX01	16gb	16GB	${true}	${HOST}/ex01_test
	Push Capture  ${CDST}	${HOST}/ex01_test	${PDST}	${HOST}/ex01_push_test

IMAGE_CAPTURE_DD_DMG
	Capture DriveToFile	DD	2gb	2GB	${false}	${HOST}/ddmg_test
	Capture DriveToFile	DMG	4gb	4GB	${false}	${HOST}/ddmg_test
	Capture DriveToFile	DD	8gb	8GB	${false}	${HOST}/ddmg_test
	Capture DriveToFile	DMG	16gb	16GB	${false}	${HOST}/ddmg_test
	Push Capture  ${CDST}	${HOST}/ddmg_test	${PDST}	${HOST}/ddmg_push_test
